function love.load()
  -- Set character properties
  man = {}
  man.posX = 100
  man.posY = 200
  man.size = 20
  man.speed = 1
  man.friction = 0.1
  man.keyLeft = "left"
  man.keyRight = "right"
  man.keyUp = "up"
  man.keyDown = "down"

  man.moveLeft = false
  man.moveRight = false
  man.moveUp = false
  man.moveDown = false
  man.forceX = 0
  man.forceY = 0

  -- Timestep for fixed timer
  timer = {}
  timer.step = 0.01
  timer.remain = 0
  timer.cycles = 0

  -- Slow mode is off by default
  slowMode = false
end

function love.keypressed(k)
  -- Quit if escape was pressed
  if k == "escape" then love.event.push("quit") end

  -- Toggle slow mode
  if k == " " then slowMode = not slowMode end

  -- Player control
  if k == man.keyLeft  then man.moveLeft  = true end
  if k == man.keyRight then man.moveRight = true end
  if k == man.keyUp    then man.moveUp    = true end
  if k == man.keyDown  then man.moveDown  = true end
end

function love.keyreleased(k)
  -- Player control
  if k == man.keyLeft  then man.moveLeft  = false end
  if k == man.keyRight then man.moveRight = false end
  if k == man.keyUp    then man.moveUp    = false end
  if k == man.keyDown  then man.moveDown  = false end
end

function love.update(dt)
  -- Move out character with framerate-independent speed
  timer.remain = timer.remain + dt
  timer.cycles = 0

  while timer.remain > timer.step do
    timer.remain = timer.remain - timer.step
    timer.cycles = timer.cycles + 1

    -- Add controlling force
    if man.moveLeft  then man.forceX = man.forceX - man.speed end
    if man.moveRight then man.forceX = man.forceX + man.speed end
    if man.moveUp    then man.forceY = man.forceY - man.speed end
    if man.moveDown  then man.forceY = man.forceY + man.speed end

    -- Smooth movement
    man.forceX = man.forceX * (1 - man.friction)
    man.forceY = man.forceY * (1 - man.friction)

    -- Change the position itself
    man.posX = man.posX + man.forceX
    man.posY = man.posY + man.forceY
  end
end

function love.draw()
  -- Draw our character
  love.graphics.setColor(255, 0, 0)
  love.graphics.circle("fill", man.posX, man.posY, man.size)

  -- Print some useful info
  love.graphics.setColor(255, 255, 255)
  love.graphics.print("Use arrow keys to move, space to toggle slow mode.", 10, 10)
  love.graphics.print("Delta: " .. love.timer.getDelta(), 10, 30)
  love.graphics.print("Remain: " .. string.format("%.3f", timer.remain), 10, 50)
  love.graphics.print("Cycles: " .. timer.cycles, 10, 70)

  -- Emulate a slower computer
  if slowMode then love.timer.sleep(0.05) end
end
